@@ -1,11 +1,13 @@
 package Google::Adwords::AdGroupService;
 use strict; use warnings;
 
-use version; our $VERSION = qv('0.0.1');
+use version; our $VERSION = qv('0.0.2');
 
 use base 'Google::Adwords::Service';
 use Date::Manip;
 
+use Google::Adwords::AdGroup;
+use Google::Adwords::StatsRecord;
 
 ### INSTANCE METHOD ################################################
 # Usage      : 
@@ -490,7 +492,7 @@ AdGroupService API calls
  
 =head1 VERSION
  
-This documentation refers to Google::Adwords::AdGroupService version 0.0.1
+This documentation refers to Google::Adwords::AdGroupService version 0.0.2
  
 =head1 SYNOPSIS
  
@@ -510,7 +512,8 @@ This documentation refers to Google::Adwords::AdGroupService version 0.0.1
     # need to login to the Adwords service
     $adgroup_service->email($email_address)
                      ->password($password)
-                     ->token($developer_token);
+                     ->developerToken($developer_token)
+                     ->applicationToken($application_token);
 
     # if you use a MCC
     #$adgroup_service->clientEmail($client_email);
