@@ -1,11 +1,15 @@
 package Google::Adwords::CampaignService;
 use strict; use warnings;
 
-use version; our $VERSION = qv('0.1.1');
+use version; our $VERSION = qv('0.1.2');
 
 use base 'Google::Adwords::Service';
 use Date::Manip;
 
+# data types
+use Google::Adwords::Campaign;
+use Google::Adwords::StatsRecord;
+
 
 ### INSTANCE METHOD ################################################
 # Usage      : 
@@ -42,6 +46,12 @@ sub addCampaign
             'status' => $campaign->status )->type('');
     }
 
+    # start_day
+    if (defined $campaign->startDay) {
+        push @campaign_params, SOAP::Data->name(
+            'startDay' => $campaign->startDay )->type('');
+    }
+
     # end_day
     if (defined $campaign->endDay) {
         push @campaign_params, SOAP::Data->name(
@@ -161,6 +171,12 @@ sub addCampaignList
                 'status' => $_->status )->type('');
         }
     
+        # start_day
+        if (defined $_->startDay) {
+            push @campaign_params, SOAP::Data->name(
+                'startDay' => $_->startDay )->type('');
+        }
+    
         # end_day
         if (defined $_->endDay) {
             push @campaign_params, SOAP::Data->name(
@@ -715,7 +731,7 @@ CampaignService API calls
  
 =head1 VERSION
  
-This documentation refers to Google::Adwords::CampaignService version 0.1.1
+This documentation refers to Google::Adwords::CampaignService version 0.1.2
  
  
 =head1 SYNOPSIS
@@ -741,7 +757,8 @@ This documentation refers to Google::Adwords::CampaignService version 0.1.1
     # need to login to the Adwords service
     $campaign_service->email($email_address)
                      ->password($password)
-                     ->token($developer_token);
+                     ->developerToken($developer_token)
+                     ->applicationToken($application_token);
 
     # if you have a MCC
     $campaign_service->clientEmail($client_email);
